==> haskell-edisonapi-1.3.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 EdisonAPI
version:              1.3.3
visibility:           public
id:                   EdisonAPI-1.3.3-ItoWm9V1vOIJptPGFcPFBU
key:                  EdisonAPI-1.3.3-ItoWm9V1vOIJptPGFcPFBU
license:              MIT
maintainer:           robdockins AT fastmail DOT fm
author:               Chris Okasaki
stability:            Stable
homepage:             http://rwd.rdockins.name/edison/home/
synopsis:
    A library of efficient, purely-functional data structures (API)

description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.

category:             Data Structures
abi:                  82bee26d06f3952691d1462c55143278
exposed:              True
exposed-modules:
    Data.Edison Data.Edison.Assoc Data.Edison.Coll
    Data.Edison.Coll.Utils Data.Edison.Prelude Data.Edison.Seq
    Data.Edison.Seq.ListSeq Data.Edison.Sym

import-dirs:          /usr/lib/ghc-9.0.2/site-local/EdisonAPI-1.3.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/EdisonAPI-1.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edisonapi
hs-libraries:         HSEdisonAPI-1.3.3-ItoWm9V1vOIJptPGFcPFBU
depends:              base-4.15.1.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html:         /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisonapi-1.3.3.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 EdisonAPI
version:              1.3.3.1
visibility:           public
id:                   EdisonAPI-1.3.3.1-AxSZpAi2KOkByzt6cjhsCE
key:                  EdisonAPI-1.3.3.1-AxSZpAi2KOkByzt6cjhsCE
license:              MIT
maintainer:           robdockins AT fastmail DOT fm
author:               Chris Okasaki
stability:            Stable
homepage:             http://rwd.rdockins.name/edison/home/
synopsis:
    A library of efficient, purely-functional data structures (API)

description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.

category:             Data Structures
abi:                  6321cf0a86793ce067fd6d5f14aef7fe
exposed:              True
exposed-modules:
    Data.Edison Data.Edison.Assoc Data.Edison.Coll
    Data.Edison.Coll.Utils Data.Edison.Prelude Data.Edison.Seq
    Data.Edison.Seq.ListSeq Data.Edison.Sym

import-dirs:          /usr/lib/ghc-9.2.8/site-local/EdisonAPI-1.3.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/EdisonAPI-1.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edisonapi
hs-libraries:         HSEdisonAPI-1.3.3.1-AxSZpAi2KOkByzt6cjhsCE
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html:         /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
